Other optical methods
=====================

Finally, the optical properties of the solar cell can be defined with a simple Beer-Lambert formalism and also provided externally by the user. These section describe the methods that are called internally by the solar cell solver in these two cases.

.. toctree::
    :maxdepth: 2

    other_methods

Beer-Lambert law
----------------

.. automodule:: solcore.optics.beer_lambert
    :members:
    :undoc-members:

External optics
---------------

.. automodule:: solcore.optics.external_optics
    :members:
    :undoc-members:
